@@ -5,12 +5,10 @@ from sql.conditionals import Case
 
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import If, Eval, Bool
-from trytond.transaction import Transaction
 from trytond import backend
 from trytond.pool import PoolMeta
 
 __all__ = ['ProductLocation', 'ShipmentIn', 'ShipmentOutReturn']
-__metaclass__ = PoolMeta
 
 
 class ProductLocation(ModelSQL, ModelView):
@@ -40,8 +38,7 @@ class ProductLocation(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         super(ProductLocation, cls).__register__(module_name)
 
@@ -55,6 +52,7 @@ class ProductLocation(ModelSQL, ModelView):
 
 
 class ShipmentIn:
+    __metaclass__ = PoolMeta
     __name__ = 'stock.shipment.in'
 
     @classmethod
@@ -70,6 +68,7 @@ class ShipmentIn:
 
 
 class ShipmentOutReturn:
+    __metaclass__ = PoolMeta
     __name__ = 'stock.shipment.out.return'
 
     @classmethod
